import React from 'react';
import ReactDOM from 'react-dom';
import { interpolateYlOrRd, scaleSequential, max } from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useData } from './useData';
import { useCodes } from './useCodes';
import { Marks } from './Marks';

const width = window.innerWidth;
const height = window.innerHeight;
const selectedYear = "2017";

const App = () => {
  const worldAtlas = useWorldAtlas();
  const data = useData();
  const codes = useCodes();

  if (!worldAtlas || !data || !codes) {
    return <pre>Loading...</pre>;
  }
  
  // Define Alpha3 Code to Numeric Code Mapper
  const numericCodeByAlphaCode = new Map();
  codes.forEach(code => {
    const alpha3Code = code['alpha-3'];
    const numericCode = code['country-code'];
    numericCodeByAlphaCode.set(alpha3Code, numericCode);
  });
  
  // Filtering by a single year
  const filteredData = data.filter(d => d.Year === selectedYear);
  
  // For each row of HIV/AIDS data, map from a numeric code to the row
  const rowByNumericCode = new Map();
  filteredData.forEach(d => {
    const alpha3Code = d.Code;
    const numericCode = numericCodeByAlphaCode.get(alpha3Code);
    rowByNumericCode.set(numericCode, d);
  });
  
  const colorValue = d => d.aids;
  
  // For scaleSequential, we need to pass an interpolator to the constructor
  // instead of setting .range()
  const colorScale = scaleSequential(interpolateYlOrRd)
  	.domain([0, max(data, colorValue)]);
	
  return (
    <svg width={width} height={height}>
      <Marks
        worldAtlas={worldAtlas}
        rowByNumericCode={rowByNumericCode}
        colorScale={colorScale}
        colorValue={colorValue}
      />
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
