import React, { useState, useEffect } from 'react';
import { json } from 'd3';
import { feature, mesh } from 'topojson';

// url for topojson data
const jsonUrl = 'https://unpkg.com/world-atlas@2.0.2/countries-50m.json';

export const useWorldAtlas = () => {
  const [data, setData] = useState(null);
  
  useEffect(() => {
    json(jsonUrl).then(topology => {
      // we need to convert topojson data into Geojson data
      // because Geojson format is easier to work with 
      // (it provides coordinates that we can directly feed into path elements)
      const { countries, land } = topology.objects;
      setData({
        countries: feature(topology, countries),
        interiors: mesh(topology, countries, (a, b) => a !== b)
      });
    });
  }, []);
  
  return data;
};
